"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _taggedTemplateLiteral2 = _interopRequireDefault(require("@babel/runtime/helpers/taggedTemplateLiteral"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireWildcard(require("styled-components"));

var _antd = require("antd");

var _icons = require("@ant-design/icons");

var _htmlReactParser = _interopRequireDefault(require("html-react-parser"));

var _immer = _interopRequireDefault(require("immer"));

var _Input = _interopRequireDefault(require("../Input"));

var _MenuPicker = _interopRequireDefault(require("../MenuPicker"));

var _utils = require("../../utils");

var _store = require("../../store");

var _theme = require("../../theme");

var _templateObject, _templateObject2, _templateObject3;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

const Menu = props => {
  const {
    value = [],
    maxLevel = 3,
    onChange
  } = props;
  const [{
    editorState: {
      siteHasChanged
    }
  }] = (0, _store.useStore)();
  const [editing, setEditing] = (0, _react.useState)([]);
  const [items, setItems] = (0, _react.useState)([]);
  const [modal, setModal] = (0, _react.useState)(false); // When a post is saved while a menu item is open, we need to manually reset the editing array to allow dragging

  (0, _react.useEffect)(() => {
    !siteHasChanged && setEditing([]);
  }, [siteHasChanged]);
  (0, _react.useEffect)(() => {
    if (value && Array.isArray(value)) {
      setItems((0, _utils.deepCopyTree)(value));
    }
  }, [value]); // Function provided by Ant Design

  const onDrop = info => {
    const dropKey = info.node.props.eventKey;
    const dragKey = info.dragNode.props.eventKey;
    const dropPos = info.node.props.pos.split('-');
    const dropPosition = info.dropPosition - Number(dropPos[dropPos.length - 1]);

    const getLevel = () => {
      const dropPos = info.node.props.pos.split('-'); // if item is dragged NOT to the top of a node the array will have an additional parameter

      let level = info.dropToGap ? dropPos.length - 1 : dropPos.length;

      const countChildren = (node, index) => {
        var _node$children;

        let newIndex = index;

        if (node !== null && node !== void 0 && (_node$children = node.children) !== null && _node$children !== void 0 && _node$children.length) {
          newIndex = countChildren(node.children, newIndex + 1);
        }

        return newIndex;
      }; // We have to check if the node has children because they could potentially exceed the max level restriction


      if (info.dragNode.children.length) {
        level = level + countChildren(info.dragNode, 0);
      }

      return level;
    };

    if (getLevel() > Number(maxLevel)) {
      return _antd.message.error({
        content: "Exceeded max depth of ".concat(maxLevel)
      });
    }

    const loop = (data, key, callback) => {
      for (let i = 0; i < data.length; i++) {
        if (data[i].key === key) {
          return callback(data[i], i, data);
        }

        if (data[i].children) {
          loop(data[i].children, key, callback);
        }
      }
    };

    const data = [...items]; // Find dragObject

    let dragObj;
    loop(data, dragKey, (item, index, arr) => {
      arr.splice(index, 1);
      dragObj = item;
    });

    if (!info.dropToGap) {
      // Drop on the content
      loop(data, dropKey, item => {
        item.children = item.children || []; // where to insert

        item.children.push(dragObj);
      });
    } else if ((info.node.props.children || []).length > 0 && // Has children
    info.node.props.expanded && // Is expanded
    dropPosition === 1 // On the bottom gap
    ) {
        loop(data, dropKey, item => {
          item.children = item.children || []; // where to insert

          item.children.unshift(dragObj);
        });
      } else {
      let ar;
      let i;
      loop(data, dropKey, (item, index, arr) => {
        ar = arr;
        i = index;
      });

      if (dropPosition === -1) {
        ar.splice(i, 0, dragObj);
      } else {
        ar.splice(i + 1, 0, dragObj);
      }
    }

    onChange(data);
  };

  const handleUpdate = (e, name, key) => {
    const updateItem = (parentNode, child, params) => {
      if (child.key === params.key) {
        return _objectSpread(_objectSpread({}, child), {}, {
          [name]: params.value
        });
      }

      return child;
    };

    const newItems = (0, _utils.recursivelyUpdateTree)({
      children: items
    }, updateItem, {
      key,
      value: e.target.value
    });
    onChange(newItems);
  };

  const handleRemove = key => {
    const newItems = (0, _utils.removeFromTree)({
      children: [...items]
    }, key);
    onChange(newItems.children); // Remove key from array

    const nextValue = (0, _immer.default)(editing, draft => {
      if (draft.includes(key)) {
        draft = draft.filter(k => k !== key);
      }

      return draft;
    });
    setEditing(nextValue);
  };

  const handleAdd = item => {
    const nextValue = (0, _immer.default)(items, draft => {
      draft.push(item);
      return draft;
    });
    onChange(nextValue);
  };

  const handleToggleCollapse = key => {
    const nextValue = (0, _immer.default)(editing, draft => {
      if (draft.includes(key)) {
        draft = draft.filter(k => k !== key);
      } else {
        draft.push(key);
      }

      return draft;
    });
    setEditing(nextValue);
  };

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(Container, null, /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_antd.Tree, {
    className: "draggable-tree",
    draggable: editing.length === 0,
    showLine: true,
    blockNode: true,
    onDrop: onDrop,
    treeData: items,
    titleRender: node => {
      return /*#__PURE__*/_react.default.createElement(_antd.Collapse, {
        ghost: true,
        onChange: () => handleToggleCollapse(node.key)
      }, /*#__PURE__*/_react.default.createElement(_antd.Collapse.Panel, {
        header: /*#__PURE__*/_react.default.createElement("span", {
          style: {
            cursor: editing.length === 0 ? 'grab' : 'not-allowed'
          }
        }, (0, _htmlReactParser.default)(node.title || ' ')),
        showArrow: false
      }, /*#__PURE__*/_react.default.createElement(_antd.Space, {
        direction: "vertical"
      }, /*#__PURE__*/_react.default.createElement(_Input.default, {
        label: "title",
        value: node.title,
        onChange: e => handleUpdate(e, 'title', node.key)
      }), /*#__PURE__*/_react.default.createElement(_Input.default, {
        label: "Url",
        value: node.url,
        onChange: e => handleUpdate(e, 'url', node.key),
        disabled: node.postTypeID
      }), /*#__PURE__*/_react.default.createElement(_antd.Button, {
        size: "small",
        danger: true,
        children: "Remove",
        onClick: () => handleRemove(node.key),
        disabled: node.children.length > 0
      }))));
    }
  })), /*#__PURE__*/_react.default.createElement(AddButton, {
    items: items && items.length > 0,
    onClick: () => setModal(true)
  }, /*#__PURE__*/_react.default.createElement(_icons.PlusOutlined, null)))), /*#__PURE__*/_react.default.createElement(_antd.Modal, {
    title: 'Menu Items',
    visible: modal,
    onCancel: () => setModal(false),
    width: 600,
    footer: null
  }, /*#__PURE__*/_react.default.createElement(_MenuPicker.default, {
    onAdd: handleAdd
  })));
};

const Container = _styledComponents.default.div(_templateObject || (_templateObject = (0, _taggedTemplateLiteral2.default)(["\n  && {\n    overflow: auto;\n\n    .ant-tree {\n      background-color: transparent;\n    }\n\n    .ant-tree-list-holder {\n      padding-top: 6px;\n    }\n\n    .ant-collapse {\n      background-color: transparent;\n      border: none !important;\n    }\n\n    .ant-collapse-header {\n      padding: 5px !important;\n    }\n\n    .ant-tree-switcher-line-icon {\n      transform: translateY(3px);\n    }\n\n    .ant-tree-node-content-wrapper {\n      padding: 0;\n\n      &:hover {\n        background-color: transparent;\n      }\n    }\n    .ant-tree-node-content-wrapper.ant-tree-node-selected {\n      background-color: transparent;\n    }\n\n    .ant-collapse-content-box {\n      padding-top: 0 !important;\n    }\n\n    .ant-collapse-content > .ant-collapse-content-box {\n      border-bottom: none;\n      background: transparent;\n    }\n\n    .rst__rowContents {\n      min-width: 150px;\n    }\n  }\n"])));

const AddButton = _styledComponents.default.div(_templateObject2 || (_templateObject2 = (0, _taggedTemplateLiteral2.default)(["\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  height: 46px;\n  width: 100%;\n  border: 1px solid transparent;\n  cursor: pointer;\n  transition: ease-in all 0.2s;\n\n  &:hover {\n    border-color: ", ";\n  }\n\n  ", "\n"])), _theme.colors.tertiary, (_ref) => {
  let {
    items
  } = _ref;
  return !items && (0, _styledComponents.css)(_templateObject3 || (_templateObject3 = (0, _taggedTemplateLiteral2.default)(["\n      border-color: ", ";\n\n      &:hover {\n        border-color: #c9cfdb;\n      }\n    "])), _theme.colors.tertiary);
});

var _default = Menu;
exports.default = _default;