"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _taggedTemplateLiteral2 = _interopRequireDefault(require("@babel/runtime/helpers/taggedTemplateLiteral"));

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _antd = require("antd");

var _reactInfiniteScroller = _interopRequireDefault(require("react-infinite-scroller"));

var _CmsLayout = _interopRequireDefault(require("../components/CmsLayout"));

var _ListItem = _interopRequireDefault(require("../components/ListItem"));

var _UserForm = _interopRequireDefault(require("../components/UserForm"));

var _actions = require("../actions");

var _store = require("../store");

var _templateObject, _templateObject2;

const Users = () => {
  const [{
    config,
    cmsState: {
      siteID,
      sites
    },
    authState: {
      authUser
    }
  }, dispatch] = (0, _store.useStore)();
  const [page, setPage] = (0, _react.useState)(null);
  const [items, setItems] = (0, _react.useState)([]);
  (0, _react.useEffect)(() => {
    loadUsers(page || 0);
  }, []);

  const loadUsers = async page => {
    if (page > -1) {
      const result = await _actions.userActions.getUsers({
        siteID,
        page,
        limit: 10
      }, dispatch, config);

      if (result) {
        setItems(items => items.concat(result.items));
        setPage(result.page);
      }
    }
  };

  const handleLoadMore = () => page && loadUsers(page);

  const handleOpenDialog = function handleOpenDialog() {
    let user = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    return dispatch({
      type: 'SET_DIALOG',
      payload: {
        open: true,
        title: user !== null && user !== void 0 && user.id ? 'Update' : 'Add',
        component: /*#__PURE__*/_react.default.createElement(_UserForm.default, (0, _extends2.default)({
          onUpdate: handleUpdate,
          onAdd: handleAdd
        }, user))
      }
    });
  };

  const handleAdd = async (_ref) => {
    let {
      email,
      role
    } = _ref;
    const result = await _actions.userActions.addUser({
      siteID,
      email,
      role
    }, dispatch, config);

    if (result) {
      setItems(items => [result, ...items]);

      _antd.message.success("Added successfully.");
    }
  };

  const handleUpdate = async (_ref2) => {
    let {
      id,
      role
    } = _ref2;
    const result = await _actions.userActions.updateUser({
      siteID,
      id,
      role
    }, dispatch, config);

    if (result) {
      setItems(items => items.map(o => o.id === result.id ? result : o));

      _antd.message.success("Saved successfully.");
    }
  };

  const handleDelete = async (_ref3) => {
    let {
      id
    } = _ref3;
    const result = await _actions.userActions.deleteUser({
      siteID,
      id
    }, dispatch, config);

    if (result) {
      setItems(items => items.filter(o => o.id !== result.id));

      _antd.message.success("Deleted successfully.");
    }
  };

  return /*#__PURE__*/_react.default.createElement(_CmsLayout.default, {
    pageTitle: "Users"
  }, /*#__PURE__*/_react.default.createElement(_antd.PageHeader, null, /*#__PURE__*/_react.default.createElement(_antd.Button, {
    children: "Add",
    onClick: handleOpenDialog,
    type: "primary"
  })), /*#__PURE__*/_react.default.createElement(StyledListItem, {
    title: authUser === null || authUser === void 0 ? void 0 : authUser.email,
    subtitle: authUser === null || authUser === void 0 ? void 0 : authUser.role
  }), /*#__PURE__*/_react.default.createElement(_reactInfiniteScroller.default, {
    pageStart: 0,
    loadMore: handleLoadMore,
    hasMore: page > -1,
    loader: /*#__PURE__*/_react.default.createElement(LoadingContainer, {
      key: 0
    }, /*#__PURE__*/_react.default.createElement(_antd.Spin, {
      size: "large"
    }))
  }, items && items.map(o => {
    const actions = [/*#__PURE__*/_react.default.createElement(_antd.Popconfirm, {
      key: "delete",
      title: "Are you sure?",
      onConfirm: () => handleDelete(o),
      okText: "Yes",
      cancelText: "No"
    }, /*#__PURE__*/_react.default.createElement(_antd.Button, {
      size: "small",
      children: "Delete",
      danger: true
    })), /*#__PURE__*/_react.default.createElement(_antd.Button, {
      key: "edit",
      size: "small",
      onClick: () => handleOpenDialog(o)
    }, "Edit")];
    return /*#__PURE__*/_react.default.createElement(StyledListItem, {
      key: o.id,
      title: o.email,
      subtitle: o.role,
      actions: actions
    });
  })));
};

const LoadingContainer = _styledComponents.default.div(_templateObject || (_templateObject = (0, _taggedTemplateLiteral2.default)(["\n  width: 100%;\n  padding: 20px;\n  display: flex;\n  justify-content: center;\n"])));

const StyledListItem = (0, _styledComponents.default)(_ListItem.default)(_templateObject2 || (_templateObject2 = (0, _taggedTemplateLiteral2.default)(["\n  margin-top: 20px;\n  margin-bottom: 20px;\n"])));
var _default = Users;
exports.default = _default;