"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.takeOverPost = exports.removePostLock = exports.refreshPostLock = exports.reorderPosts = exports.duplicatePost = exports.emptyTrash = exports.deletePost = exports.updatePost = exports.getPost = exports.addPost = void 0;

var _ = require(".");

const addPost = async (_ref, dispatch, config) => {
  let {
    siteID,
    postTypeID,
    title,
    parentID
  } = _ref;
  let result = await (0, _.db)('createPost', {
    siteID,
    title,
    postTypeID,
    parentID
  }, dispatch, config);
  return result;
};

exports.addPost = addPost;

const getPost = async (_ref2, dispatch, config) => {
  let {
    siteID,
    postID
  } = _ref2;
  let result = await (0, _.db)('getPost', {
    siteID,
    postID
  }, dispatch, config);
  return result;
};

exports.getPost = getPost;

const updatePost = async (_ref3, dispatch, config) => {
  let {
    siteID,
    id,
    postTypeID,
    title,
    slug,
    status,
    content,
    seo,
    parentID,
    taxonomies,
    featuredImage,
    template,
    templateObject
  } = _ref3;
  let result = await (0, _.db)('updatePost', {
    siteID,
    id,
    postTypeID,
    title,
    slug,
    status,
    content: JSON.stringify(content),
    seo: JSON.stringify(seo),
    parentID,
    taxonomies: JSON.stringify(taxonomies),
    featuredImage: JSON.stringify(featuredImage),
    template,
    templateObject: JSON.stringify(templateObject)
  }, dispatch, config);
  return result;
};

exports.updatePost = updatePost;

const deletePost = async (_ref4, dispatch, config) => {
  let {
    siteID,
    id
  } = _ref4;
  let result = await (0, _.db)('deletePost', {
    siteID,
    id
  }, dispatch, config);
  return result;
};

exports.deletePost = deletePost;

const emptyTrash = async (_ref5, dispatch, config) => {
  let {
    siteID,
    postTypeID
  } = _ref5;
  let result = await (0, _.db)('emptyTrash', {
    siteID,
    postTypeID
  }, dispatch, config);
  return result;
};

exports.emptyTrash = emptyTrash;

const duplicatePost = async (_ref6, dispatch, config) => {
  let {
    siteID,
    id
  } = _ref6;
  let result = await (0, _.db)('duplicatePost', {
    siteID,
    id
  }, dispatch, config);
  return result;
};

exports.duplicatePost = duplicatePost;

const reorderPosts = async (_ref7, dispatch, config) => {
  let {
    siteID,
    postIDs
  } = _ref7;
  let result = await (0, _.db)('reorderPosts', {
    siteID,
    postIDs: JSON.stringify(postIDs)
  }, dispatch, config);
  return result;
};

exports.reorderPosts = reorderPosts;

const refreshPostLock = async (_ref8, dispatch, config) => {
  let {
    siteID,
    id
  } = _ref8;
  let result = await (0, _.db)('refreshPostLock', {
    siteID,
    id
  }, dispatch, config);
  return result;
};

exports.refreshPostLock = refreshPostLock;

const removePostLock = async (_ref9, dispatch, config) => {
  let {
    siteID,
    id
  } = _ref9;
  let result = await (0, _.db)('removePostLock', {
    siteID,
    id
  }, dispatch, config);
  return result;
};

exports.removePostLock = removePostLock;

const takeOverPost = async (_ref10, dispatch, config) => {
  let {
    siteID,
    id
  } = _ref10;
  let result = await (0, _.db)('takeOverPost', {
    siteID,
    id
  }, dispatch, config);
  return result;
};

exports.takeOverPost = takeOverPost;