"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getUnpublishedChanges = exports.syncFields = exports.deploySite = exports.deleteSite = exports.updateSite = exports.addSite = exports.getSite = exports.getSites = void 0;

var _ = require(".");

var _utils = require("../utils");

// import app components
const getSites = async (_ref, dispatch, config) => {
  let {} = _ref;
  let result = await (0, _.db)('getSites', {}, dispatch, config);

  if (result) {
    result = result.reduce((obj, item) => {
      obj[item.id] = item;
      return obj;
    }, {});
  }

  return result;
};

exports.getSites = getSites;

const getSite = async (_ref2, dispatch, config) => {
  let {
    siteID
  } = _ref2;
  let result = await (0, _.db)('getSite', {
    siteID
  }, dispatch, config);

  if (result) {
    result = (0, _utils.formatSite)(result);
  }

  return result;
};

exports.getSite = getSite;

const addSite = async (_ref3, dispatch, config) => {
  let {
    title
  } = _ref3;
  let result = await (0, _.db)('createSite', {
    title
  }, dispatch, config);

  if (result) {
    result = (0, _utils.formatSite)(result);
  }

  return result;
};

exports.addSite = addSite;

const updateSite = async (_ref4, dispatch, config) => {
  let {
    id,
    themeOptions,
    frontPage,
    deployment,
    title,
    siteUrl,
    googleMapsApi,
    apiKey,
    editorOptions
  } = _ref4;
  let result = await (0, _.db)('updateSite', {
    id,
    title,
    frontPage,
    siteUrl,
    googleMapsApi,
    apiKey,
    themeOptions: JSON.stringify(themeOptions),
    deployment: JSON.stringify(deployment),
    editorOptions: JSON.stringify(editorOptions)
  }, dispatch, config);

  if (result) {
    result = (0, _utils.formatSite)(result);
  }

  return result;
};

exports.updateSite = updateSite;

const deleteSite = async (_ref5, dispatch, config) => {
  let {
    id
  } = _ref5;
  let result = await (0, _.db)('deleteSite', {
    id
  }, dispatch, config);

  if (result) {
    result = (0, _utils.formatSite)(result);
  }

  return result;
};

exports.deleteSite = deleteSite;

const deploySite = async (_ref6, dispatch, config) => {
  let {
    id
  } = _ref6;
  let result = await (0, _.db)('deploySite', {
    id
  }, dispatch, config);

  if (result) {
    result = (0, _utils.formatSite)(result);
  }

  return result;
};

exports.deploySite = deploySite;

const syncFields = async (_ref7, dispatch, config) => {
  let {
    fields,
    apiKey
  } = _ref7;
  let result = await (0, _.db)('syncFields', {
    fields: JSON.stringify(fields),
    apiKey
  }, dispatch, config);

  if (result) {
    result = (0, _utils.formatSite)(result);
  }

  return result;
};

exports.syncFields = syncFields;

const getUnpublishedChanges = async (_ref8, dispatch, config) => {
  let {
    siteID
  } = _ref8;
  const result = await (0, _.db)('getUnpublishedChanges', {
    siteID
  }, dispatch, config);
  return result;
};

exports.getUnpublishedChanges = getUnpublishedChanges;