"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useStore = exports.StoreProvider = exports.StateContext = void 0;

var _react = _interopRequireWildcard(require("react"));

var _utils = require("../utils");

var _configState = require("./configState");

var _authState = require("./authState");

var _appState = require("./appState");

var _editorState = require("./editorState");

var _cmsState = require("./cmsState");

const StateContext = /*#__PURE__*/(0, _react.createContext)({});
exports.StateContext = StateContext;

const StoreProvider = (_ref) => {
  let {
    children,
    source,
    settings,
    siteID = 'default',
    fields,
    onLogout
  } = _ref;
  const config = {
    source,
    settings,
    siteID,
    fields: (0, _utils.formatFields)(fields),
    onLogout
  };
  const initialState = {
    config,
    authState: _authState.authState,
    appState: _appState.appState,
    editorState: _editorState.editorState,
    cmsState: _cmsState.cmsState
  };

  const reducer = (_ref2, action) => {
    let {
      authState,
      appState,
      editorState,
      cmsState
    } = _ref2;
    return {
      config: (0, _configState.configReducer)(config, action),
      authState: (0, _authState.authReducer)(authState, action),
      appState: (0, _appState.appReducer)(appState, action),
      editorState: (0, _editorState.editorReducer)(editorState, action),
      cmsState: (0, _cmsState.sitesReducer)(cmsState, action)
    };
  };

  return /*#__PURE__*/_react.default.createElement(StateContext.Provider, {
    value: (0, _react.useReducer)(reducer, initialState)
  }, children);
};

exports.StoreProvider = StoreProvider;

const useStore = () => (0, _react.useContext)(StateContext);

exports.useStore = useStore;