"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.logout = exports.getCurrentUser = exports.isPreview = exports.isLoggedIn = exports.getUser = exports.setUser = void 0;

var _gatsby = require("gatsby");

var _getStorageKey = _interopRequireDefault(require("./getStorageKey"));

var _getParameter = _interopRequireDefault(require("./getParameter"));

const storageKey = (0, _getStorageKey.default)();
const isBrowser = typeof window !== "undefined";

const setUser = user => {
  if (storageKey) {
    window.localStorage[storageKey] = JSON.stringify(user);
  }
};

exports.setUser = setUser;

const getUser = () => {
  if (storageKey && window.localStorage[storageKey]) {
    let user = JSON.parse(window.localStorage[storageKey]);
    return user ? user : {};
  }

  return {};
};

exports.getUser = getUser;

const isLoggedIn = () => {
  if (!isBrowser) {
    return false;
  }

  const user = getUser();

  if (user) {
    return !!user.authToken;
  }

  return false;
};

exports.isLoggedIn = isLoggedIn;

const isPreview = () => {
  if (!isBrowser) {
    return false;
  }

  const preview = (0, _getParameter.default)('preview');

  if (!preview) {
    return false;
  }

  return preview;
};

exports.isPreview = isPreview;

const getCurrentUser = () => isBrowser && getUser();

exports.getCurrentUser = getCurrentUser;

const logout = config => {
  if (!isBrowser) {
    return;
  }

  console.log(config === null || config === void 0 ? void 0 : config.onLogout);
  setUser({});
  typeof config.onLogout === 'function' ? config.onLogout() : (0, _gatsby.navigate)('/');
};

exports.logout = logout;